@@ -275,11 +275,11 @@ def create_exist_pipeline_file(type, fileName):
 
         new_file = folder + "/" + fileName + ".py"
         current_init_file = folder + "/__init__.py"
-        new_init_export = "from " + currentDir + '.' + fileName + " import " + className
+        new_init_export = "from " + '.' + fileName + " import " + className
 
         create_file(new_file, data)
         create_init_file(current_init_file, new_init_export)
-        inject_to_pipeline(fileName, className, new_init_export)
+        inject_to_pipeline(fileName, type, className, new_init_export)
     else:
         print('please create a project and go to project location first')
     pass
@@ -330,7 +330,7 @@ def create_tester_env():
 
 
 def read_template_file(filename):
-    with open(os.path.join(__location__, 'cli/' + filename + '_template.py'), 'r') as file:
+    with open(os.path.join(__location__, 'dsframework/cli/' + filename + '_template.py'), 'r') as file:
         data = file.read()
         return data
 
@@ -370,7 +370,7 @@ def replace_in_template_and_create_file(project_name, folder, pipelineType, data
 
     if createInitFile:
         new_init_file = folder + "/__init__.py"
-        new_init_export = "from " + currentDirNoMainDir + '.' + pipelineType + " import " + className
+        new_init_export = "from " + '.' + pipelineType + " import " + className
         create_init_file(new_init_file, new_init_export)
 
 
@@ -400,7 +400,7 @@ def create_init_file(init_path, init_export):
             f.close()
 
 
-def inject_to_pipeline(fileName, className, new_init_export):
+def inject_to_pipeline(fileName, type, className, new_init_export):
     file_path = 'pipeline/pipeline.py'
     if os.path.exists(file_path):
         data = read_file(file_path)
@@ -419,8 +419,9 @@ def inject_to_pipeline(fileName, className, new_init_export):
             build_pipeline_indent = (index_of_build_pipeline.start() - index_of_build_pipeline_row.start()) * 2
             new_tab_line = new_tab_line.ljust(build_pipeline_indent + 1)
 
-        new_component_line = 'self.' + fileName + ' = ' + className + '()'
-        add_component_line = 'self.add_component(self.' + fileName + ')'
+        attr = fileName + type.title()
+        new_component_line = 'self.' + attr + ' = ' + className + '()'
+        add_component_line = 'self.add_component(self.' + attr + ')'
 
         # finding imports and add components indexes
         last_index_of_add_component = -1
@@ -485,7 +486,7 @@ def inject_to_pipeline(fileName, className, new_init_export):
 
 
 def create_project_config_yaml():
-    with open(os.path.join(__location__, 'cli/config.yaml'), 'r') as file:
+    with open(os.path.join(__location__, 'dsframework/cli/config.yaml'), 'r') as file:
         data = file.read()
         data = data.replace('generatedDirectory', directories['main'])
         new_file = directories['main'] + '/pipeline/config.yaml'
@@ -496,7 +497,7 @@ def create_project_config_yaml():
 
 
 def create_project_config_json():
-    with open(os.path.join(__location__, 'cli/config.json'), 'r') as file:
+    with open(os.path.join(__location__, 'dsframework/cli/config.json'), 'r') as file:
         data = file.read()
         data = data.replace('generatedDirectory', directories['main'])
         new_file = directories['main'] + '/config/config.json'
@@ -507,7 +508,7 @@ def create_project_config_json():
 
 
 def create_project_gitignore():
-    with open(os.path.join(__location__, 'cli/.gitignore'), 'r') as file:
+    with open(os.path.join(__location__, 'dsframework/cli/.gitignore'), 'r') as file:
         data = file.read()
         new_file = directories['main'] + '/.gitignore'
         if not os.path.exists(new_file):
@@ -517,7 +518,7 @@ def create_project_gitignore():
 
 
 def create_server_config_json():
-    with open(os.path.join(__location__, 'cli/cors_allowed_origins.json'), 'r') as file:
+    with open(os.path.join(__location__, 'dsframework/cli/cors_allowed_origins.json'), 'r') as file:
         data = file.read()
         data = data.replace('generatedDirectory', directories['main'])
         new_file = directories['server'] + '/cors_allowed_origins.json'
@@ -553,7 +554,7 @@ def copy_deploy_files(main_dir):
     currentPipelineFolder = os.path.basename(os.getcwd())
     if main_dir:
         currentPipelineFolder = main_dir
-    dir = os.path.join(__location__, 'cli/tester/deploy_files/')
+    dir = os.path.join(__location__, 'dsframework/cli/tester/deploy_files/')
     listOfFiles = list()
     for (dirpath, dirname, filenames) in os.walk(dir):
         dirpath = dirpath.replace(dir, '')
@@ -594,7 +595,7 @@ def copy_cloud_eval_files(main_dir):
     service_folder = str(currentPipelineFolder)
     service_name = service_folder.split('/')[-1]
     project_name_no_underscore = clean_existing_project_name(service_name)
-    dir = os.path.join(__location__, 'cli/tester/cloud_eval/')
+    dir = os.path.join(__location__, 'dsframework/cli/tester/cloud_eval/')
     listOfFiles = list()
     conflicted_files = []
     for (dirpath, dirname, filenames) in os.walk(dir):
