@@ -2,6 +2,8 @@
 # coding: utf-8
 
 from typing import List, Any
+import sys
+import pathlib
 import os
 import json
 import csv
@@ -18,8 +20,10 @@ class ZIDS_SharedArtifacts():
         self.load_artifacts()
 
     def load_config_json(self):
-        if os.path.exists('config/config.json'):
-            data = functions.load_json('config/config.json')
+        file_path = sys.modules[self.__class__.__module__].__file__
+        curr_path = file_path[:file_path.index("pipeline")]
+        if os.path.exists(curr_path + 'config/config.json'):
+            data = functions.load_json(curr_path + 'config/config.json')
             for item in data:
                 setattr(self, item, data[item])
 
